@@ -73,6 +73,8 @@ def repo_status(api_instance, options):
     params.distro_hash = options.distro_hash
     if options.success:
         params.success = str(options.success)
+    if options.extended_hash and options.extended_hash != 'None':
+        params.extended_hash = options.extended_hash
 
     try:
         api_response = api_instance.api_repo_status_get(params)
@@ -98,7 +100,10 @@ def repo_promote(api_instance, options):
     params = dlrnapi_client.Promotion()  # Promotion | The JSON params to post
     params.commit_hash = options.commit_hash
     params.distro_hash = options.distro_hash
-    params.extended_hash = options.extended_hash
+    if options.extended_hash != 'None':
+        params.extended_hash = options.extended_hash
+    else:
+        params.extended_hash = None
     params.promote_name = options.promote_name
     try:
         api_response = api_instance.api_promote_post(params)
@@ -114,14 +119,17 @@ def repo_promote_batch(api_instance, options):
         pair_list = pair.split('_')
         commit_hash = pair_list[0]
         distro_hash = pair_list[1]
-        if len(pair_list > 2):
+        if len(pair_list) > 2:
             extended_hash = '_'.join(pair_list[2:])
         else:
             extended_hash = None
         param = dlrnapi_client.Promotion()
         param.commit_hash = commit_hash
         param.distro_hash = distro_hash
-        param.extended_hash = extended_hash
+        if extended_hash == 'None':
+            param.extended_hash = None
+        else:
+            param.extended_hash = extended_hash
         param.promote_name = options.promote_name
         params.append(param)
     try:
@@ -137,7 +145,7 @@ def get_promotions(api_instance, options):
         params.commit_hash = options.commit_hash
     if options.distro_hash:
         params.distro_hash = options.distro_hash
-    if options.extended_hash:
+    if options.extended_hash and options.extended_hash != 'None':
         params.extended_hash = options.extended_hash
     if options.agg_hash:
         params.aggregate_hash = options.agg_hash
@@ -167,6 +175,8 @@ def report_result(api_instance, options):
     params.url = options.info_url
     params.timestamp = options.timestamp
     params.notes = options.notes
+    if options.extended_hash and options.extended_hash != 'None':
+        params.extended_hash = options.extended_hash
 
     if (params.commit_hash and not params.distro_hash) or\
        (not params.commit_hash and params.distro_hash):
@@ -242,7 +252,7 @@ def main():
                         )
     parser.add_argument('--password', '-p',
                         help='password for authentication, defaults to '
-                             '"DLRNAPI_PASSWORD" environment variable is set',
+                             '"DLRNAPI_PASSWORD" environment variable if set',
                         default=os.getenv('DLRNAPI_PASSWORD', None)
                         )
 
@@ -321,6 +331,9 @@ def main():
     parser_st.add_argument('--distro-hash', type=str, required=True,
                            help='distro_hash of the repo to fetch '
                                 'information for.')
+    parser_st.add_argument('--extended-hash', type=str, required=False,
+                           help='extended_hash of the repo to fetch '
+                                'information for.')
     parser_st.add_argument('--success', type=str, default=None,
                            help='If set to a value (true/false), only return '
                                 'the CI reports with the specified vote. If '
@@ -347,6 +360,8 @@ def main():
                             help='commit_hash of tested repo')
     parser_rep.add_argument('--distro-hash', type=str, required=False,
                             help='distro_hash of tested repo')
+    parser_rep.add_argument('--extended-hash', type=str, required=False,
+                            help='extended_hash of tested repo')
     parser_rep.add_argument('--agg-hash', type=str, required=False,
                             help='hash of the tested aggregated repo. Note '
                             'that either --commit-hash and --distro-hash or'
@@ -380,9 +395,14 @@ def main():
                                              'at the same time, as an atomic '
                                              'operation.')
     parser_prom.add_argument('--hash-pairs', type=str, required=True,
-                             help='commit_hash+distro_hash of the repos to '
-                                  'be promoted, specified as a comma-separated'
-                                  ' list of commit_distro hash pairs')
+                             help='commit_hash+distro_hash or '
+                                  'commit_hash+distro_hash+extended_hash of '
+                                  'the repos to be promoted, specified as a '
+                                  'comma-separated list of commit_distro or '
+                                  'commit_distro_extended hash groups. If no '
+                                  'extended hash is included, the latest '
+                                  'commit matching the commit and distro '
+                                  'hashes will be promoted.')
     parser_prom.add_argument('--promote-name', type=str, required=True,
                              help='Name to be used for the promotion')
 
